babel: Internationalization utilities
=====================================

Description
-----------

Internationalization utilities

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/Babel/

